@@ -128,7 +128,7 @@ KJob *NOAAIon::requestAPIJob(const QUrl &url, Callback onResult)
 
     auto receivedData = std::make_shared<QByteArray>();
 
-    connect(getJob, &KIO::TransferJob::data, this, [this, receivedData](KIO::Job *job, const QByteArray &data) {
+    connect(getJob, &KIO::TransferJob::data, this, [receivedData](KIO::Job *job, const QByteArray &data) {
         Q_UNUSED(job)
 
         if (data.isEmpty()) {
@@ -201,7 +201,7 @@ void NOAAIon::fetchForecast(std::shared_ptr<QPromise<std::shared_ptr<Forecast>>>
 
     const QList<QString> info = placeInfo.split('|'_L1);
 
-    if (info.size() == 3 && info[1] == "weather" && !m_isLegacy) {
+    if (info.size() == 3 && info[1] == "weather"_L1 && !m_isLegacy) {
         m_isLegacy = true;
         m_newPlaceInfo = info[2];
         fetchForecast(m_forecastPromise, m_newPlaceInfo);
@@ -751,7 +751,7 @@ QString NOAAIon::i18nForecast(const QString &summary) const
 
     // i18n: The forecast summary can include several single conditions that follow
     // a temporary sequence, separated by " then ". Also include spaces if necessary.
-    // If there is no suitable separtor, a sentence separator might do.
+    // If there is no suitable separator, a sentence separator might do.
     const QString separator = i18nc("Separator between forecast conditions that follow a temporal sequence (ex. \"Rain then Sunny\")", " then ");
     return i18nSummary.join(separator);
 }
